@@ -1,10 +1,32 @@
+import os
 from typing import Callable, List
 
+from tqdm import tqdm
+
+config_default_values = {"return_errors": False, "print_errors": True}
+
+
+def param_list(exec_data):
+    func = exec_data[0]
+    chunk_id = exec_data[1]
+    params = exec_data[2]
+    config = exec_data[3]
+
+    results = []
+    errors = []
+    for param in tqdm(params, desc=f"processing: - chunk_num[{str(chunk_id)}] pid[{str(os.getpid())}]"):
+        try:
+            results.append(func(param))
+        except Exception as e:
+            if config["print_errors"]:
+                print(e)
+            errors.append(e)
+    return results, errors
+
 
 def tfrq(func: Callable, params: List, num_cores=None, config=None):
     import math
     from concurrent.futures import ProcessPoolExecutor
-    from tfrq_helpers import param_list, config_default_values
     import os
 
     if num_cores is None:
